@@ -68,8 +68,8 @@ plot_tree = function(tree, type='unrooted', main=NULL, guide_size=NULL,
    geom_segment(data=x$edge, aes_string(x='x', y='y', xend='xend', yend='yend')) +
     theme_noaxis() +
     annotate('segment', x=range_x[1], xend=range_x[1]+guide_size,
-             y=range_y[1], yend=range_y[1], vjust=1,
-             arrow=arrow(ends="both",angle=90,length=unit(.2,"cm"))) +
+             y=range_y[1], yend=range_y[1],
+             arrow=arrow(ends="both",angle=90, length=unit(.2,"cm"))) +
     annotate('text', x=range_x[1]+(guide_size/2), y=range_y[1], label=guide_size, vjust=-.5)
 
   if(!is.null(rank)){
