@@ -10,9 +10,14 @@
 #' obtained using \code{\link{search_primer_pair}}
 #' @name primerTree
 #' @docType package
-#' @import ggplot2 grid XML ape httr plyr directlabels gridExtra
-#'   scales stringr foreach
+#' @import ggplot2 XML ape httr plyr directlabels gridExtra
+#'   stringr foreach
 #' @importFrom lubridate %--% seconds now
+#' @importFrom grid grid.locator
+#' @importFrom scales expand_range
+#' @importFrom grDevices dev.cur dev.off dev.set pdf
+#' @importFrom stats na.omit quantile
+#' @importFrom utils capture.output
 #' @useDynLib primerTree
 NULL
 
@@ -204,11 +209,11 @@ env2list = function(env){
 #' @param ... additional arguments passed to annotate
 #' @export
 identify.primerTree_plot = function(x, ...) {
-  point = gglocator(plot$layers[[4]])
-  distances <- distance(point, plot$layers[[4]]$data[,c('x','y')])
+  point <- gglocator(x$layers[[4]])
+  distances <- distance(point, x$layers[[4]]$data[,c('x','y')])
   closest <- which(distances == min(distances))[1]
-  point$label <- plot$layers[[4]]$data[closest,deparse(plot$layers[[4]]$mapping$colour)]
-  plot + annotate("text", label=point$label, x=point$x, y=point$y, ...)
+  point$label <- x$layers[[4]]$data[closest,deparse(x$layers[[4]]$mapping$colour)]
+  x + annotate("text", label=point$label, x=point$x, y=point$y, ...)
 }
 gglocator = function(object) {
   loc <-  as.numeric(grid.locator("npc"))
