@@ -82,11 +82,13 @@ expand_arguments <- function(...){
 #' Construct a neighbor joining tree from a dna alignment
 #'
 #' @param dna fasta dna object the tree is to be constructed from
+#' @param pairwise.deletion a logical indicating if the distance matrix should 
+#' be constructed using pairwise deletion
 #' @param ... furthur arguments to dist.dna
 #' @seealso \code{\link{dist.dna}}, \code{\link{nj}}
 #' @export
-tree_from_alignment = function(dna, ...){
-  nj(dist(dna, ...))
+tree_from_alignment = function(dna, pairwise.deletion=TRUE, ...){
+  nj(dist.dna(dna, model="N", pairwise.deletion=pairwise.deletion, ...))
 }
 #' Multiple sequence alignment with clustal omega
 #'
